# Django JSheet

Django JSheet is a little tool to render a simple excel sheet in webpage

A sheet is generated with all the data and its history.

No model is required, but you can eventually add it to allows synchronization of data with the db

There are many around, but mine is cooler because it's made by me .-.

Good luck! \o/``